@@ -865,8 +865,7 @@ test_that("Exp249", {
   #'## Add factors and variates for new analysis
   Exp249.lay <- within(Exp249.lay, 
                        { 
-                         xMainPosn <- as.numfac(MainPosn)
-                         xMainPosn <- -(xMainPosn - mean(xMainPosn))
+                         xMainPosn <- as.numfac(MainPosn, center = TRUE)
                          Mainplots <- fac.combine(list(Rows,MainPosn))
                        })
 
@@ -879,8 +878,8 @@ test_that("Exp249", {
   testthat::expect_equal(nrow(summ$aliasing), 2)
   testthat::expect_equal(ncol(summ$aliasing), 7)
   testthat::expect_equal(length(Exp249.canon$Q[[1]]), 3)
-  testthat::expect_lt(abs(Exp249.canon$Q[[1]]$'Zones'$'Lines'$adjusted$aefficiency - 0.1499827), 1e-05)
-  testthat::expect_lt(abs(Exp249.canon$Q[[1]]$'Mainplots[Zones]'$'Lines'$adjusted$aefficiency - 0.987877), 1e-05)
+  testthat::expect_lt(abs(Exp249.canon$Q[[1]]$'Zones'$'Lines'$adjusted$aefficiency - 0.1498554), 1e-04)
+  testthat::expect_lt(abs(Exp249.canon$Q[[1]]$'Mainplots[Zones]'$'Lines'$adjusted$aefficiency - 0.987877), 1e-04)
   testthat::expect_lt(abs(Exp249.canon$Q[[1]]$'Subplots[Zones:Mainplots]'$'Conditions'$adjusted$aefficiency - 1), 1e-05)
   testthat::expect_equal(Exp249.canon$Q[[2]]$'Mainplots[Zones]&Residual', 183)
   testthat::expect_equal(Exp249.canon$Q[[2]]$'Subplots[Zones:Mainplots]&Residual', 189)
@@ -917,8 +916,7 @@ test_that("Exp249_All", {
   
   Exp249.lay <- within(Exp249.lay, 
                        { 
-                         xMainPosn <- as.numfac(MainPosn)
-                         xMainPosn <- -(xMainPosn - mean(xMainPosn))
+                         xMainPosn <- as.numfac(MainPosn, center = TRUE)
                          Mainplots <- fac.combine(list(Rows,MainPosn))
                          AMainplots <- fac.combine(list(Zones, Mainplots))
                          ASubplots <- fac.combine(list(AMainplots,Subplots))
@@ -929,8 +927,8 @@ test_that("Exp249_All", {
                                  labels = "sources", data = Exp249.lay)
   summary(Exp249A.canon)
   testthat::expect_equal(length(Exp249A.canon$Q[[1]]), 3)
-  testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'Zones'$'Lines[Checks]'$adjusted$aefficiency - 0.1499827), 1e-04)
-  testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'AMainplots[Zones]'$'Lines[Checks]'$adjusted$aefficiency - 0.987877), 1e-05)
+  testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'Zones'$'Lines[Checks]'$adjusted$aefficiency - 0.1498554), 1e-04)
+  testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'AMainplots[Zones]'$'Lines[Checks]'$adjusted$aefficiency - 0.9878884), 1e-05)
   testthat::expect_lt(abs(Exp249A.canon$Q[[1]]$'ASubplots[Zones:AMainplots]'$'Conditions'$adjusted$aefficiency - 1), 1e-05)
   testthat::expect_equal(Exp249A.canon$Q[[2]]$'AMainplots[Zones]&Residual', 183)
   testthat::expect_equal(Exp249A.canon$Q[[2]]$'ASubplots[Zones:AMainplots]&Residual', 189)
